NMDP HLA Frequencies Adjusted by US 2020 Census
Source:R/data.R
nmdp_hla_frequencies_us_2020_census_adjusted.RdA dataset containing NMDP allele frequencies adjusted by race according to the 2020 US Census. The data provides a US-level summary of race-adjusted allelic frequencies, including calculated genotypic frequencies.
nmdp allele frequencies adjusted by race according to the US census. This table contains those race-adjusted alleleic frequencies summed up so we have a us-level summarization
Format
An object of class tbl_df (inherits from tbl, data.frame) with 2341 rows and 6 columns.
An object of class tbl_df (inherits from tbl, data.frame) with 2341 rows and 6 columns.
Fields
regionThe region considered (e.g., US-level).
lociThe HLA loci (e.g., A, B, or C).
alleleThe specific HLA allele.
afUS Census-adjusted allelic frequency, calculated as the sum of race-adjusted frequencies.
calc_gfGenotypic frequencies calculated from the adjusted allelic frequencies.
hla_sourceThe source of the data, indicating it was derived from
us_census_adjusted_nmdp_summed_by_race.regionWhat region was considered
loci-what loci A,B, or C
alleleWhat allele
afUS-census adjusted alleleic frequency (sum of us-census adjsuted by race afs)
calc_gfgenotypic frequencies calcualted from the af
hla_sourceus_census_adjusted_nmdp_summed_by_race